@@ -4,9 +4,6 @@
 # @Author  : lj
 # @File    : __init__.py.py
 from .singleton import Singleton
-from Header import *
-from Time import *
-
 __all__=[
     'Singleton'
 ]
\ No newline at end of file
