@@ -3,6 +3,3 @@
 # @Time    : 2022/6/20 10:09
 # @Author  : lj
 # @File    : __init__.py.py
-from Amazon import *
-from Comm import *
-from Db import *
\ No newline at end of file
